@@ -5,7 +5,7 @@ import jinja2
 import sqlalchemy as sa
 from blazeutils import tolist
 from keg.db import db
-from keg.signals import db_init_post
+from keg.signals import db_init_post, init_complete
 from webgrid.renderers import render_html_attributes
 
 import keg_auth.cli
@@ -81,6 +81,7 @@ class AuthManager(object):
         self.permissions = tolist(permissions or [])
         self._model_initialized = False
         self._loaders_initialized = False
+        self._signal_handlers = []
 
     def init_app(self, app):
         """Inits KegAuth as a flask extension on the given app."""
@@ -91,6 +92,9 @@ class AuthManager(object):
         self.init_jinja(app)
         self.init_loaders(app)
         self.init_permissions(app)
+        self.init_custom_csrf(app)
+
+        self.fix_testing_teardown(app)
 
     def init_config(self, app):
         """Provide app config defaults for crypto, mail, logins, etc."""
@@ -107,7 +111,7 @@ class AuthManager(object):
         site_abbr = app.config.get('SITE_ABBR', site_name)
         app.config.setdefault('KEGAUTH_EMAIL_SITE_ABBR', site_abbr)
 
-        app.config.setdefault('KEGAUTH_BASE_TEMPLATE', 'base-page.html')
+        app.config.setdefault('KEGAUTH_CRUD_INCLUDE_TITLE', True)
         app.config.setdefault('KEGAUTH_TEMPLATE_TITLE_VAR', 'page_title')
         app.config.setdefault('KEGAUTH_TOKEN_EXPIRE_MINS', 60 * 4)
         app.config.setdefault('KEGAUTH_LOGOUT_CLEAR_SESSION', True)
@@ -118,22 +122,12 @@ class AuthManager(object):
         # methods like OPTIONS during front-end API requests, for CORS compatibility.
         app.config.setdefault('KEGAUTH_HTTP_METHODS_EXCLUDED', [])
 
-        # Use select2 for form selects in templates extending keg_auth/form-base.
-        app.config.setdefault('KEGAUTH_USE_SELECT2', True)
-
         # Set the login target for the redirect authenticator
         app.config.setdefault('KEGAUTH_REDIRECT_LOGIN_TARGET', None)
 
         # OAuth profiles
         app.config.setdefault('KEGAUTH_OAUTH_PROFILES', [])
 
-        # Set defaults for OIDC URI locations
-        app.config.setdefault('OIDC_AUTH_URI', '/oauth2/v1/authorize')
-        app.config.setdefault('OIDC_TOKEN_URI', '/oauth2/v1/token')
-        app.config.setdefault('OIDC_ISSUER', '/oauth2')
-        app.config.setdefault('OIDC_USERINFO_URI', '/oauth2/userinfo')
-        app.config.setdefault('KEGAUTH_OIDC_LOGOUT_REDIRECT', None)
-
         # Attempt lockout parameters.
         # - Enabled: default True, turns on attempt limits and requires the attempt entity.
         # - Limit: maximum number of attempts within the timespan.
@@ -292,6 +286,32 @@ class AuthManager(object):
             if 'permissions' not in str(exc):
                 raise
 
+    def init_custom_csrf(self, app):
+        @init_complete.connect
+        def handle_custom_csrf(app):
+            if 'csrf' not in app.extensions:
+                return
+            for endpoint_key in self.endpoints.keys():
+                endpoint = self.endpoint(endpoint_key)
+                view_obj = app.view_functions.get(endpoint)
+                if (
+                    not hasattr(view_obj, 'view_class')
+                    or not hasattr(view_obj.view_class, 'auth_manager_key')
+                    or not hasattr(view_obj.view_class, 'responder_key')
+                ):
+                    # only support auth-responded class views for this right now
+                    continue
+                dest = f"{view_obj.__module__}.{view_obj.__name__}"
+                authenticator_cls = getattr(self, f'{view_obj.view_class.auth_manager_key}_cls')
+                responder_cls = authenticator_cls.responder_cls.get(
+                    view_obj.view_class.responder_key
+                )
+                if getattr(responder_cls, '_csrf_custom_handling', False):
+                    app.extensions['csrf'].exempt(dest)
+
+        # persist a reference to this method for the signal to call
+        self._signal_handlers.append(handle_custom_csrf)
+
     def validate_permission_set(self, permissions):
         defined_tokens = set(
             tolist(perm)[0] for perm in self.permissions
@@ -397,6 +417,21 @@ class AuthManager(object):
         user.token_generate()
         self.mail_manager.send_new_user(user)
 
+    def fix_testing_teardown(self, app):
+        """ Needed until https://github.com/level12/keg/issues/90 is fixed & released. """
+        if not app.config.get('TESTING', False):
+            return
+
+        version = tuple(map(lambda x: int(x), flask_login.__version__.split('.')))
+
+        if version < (0, 6, 2):
+            return
+
+        @app.teardown_request
+        def cleanup_user_cache(error):
+            if '_login_user' in flask.g:
+                del flask.g._login_user
+
 
 # ensure that any manager-attached menus are reset for auth requirements on login/logout
 def refresh_session_menus(app, user):
