@@ -1,6 +1,3 @@
-# Using unicode_literals instead of adding 'u' prefix to all stings that go to SA.
-from __future__ import unicode_literals
-
 from datetime import timedelta
 from unittest import mock
 from urllib.parse import quote
@@ -14,8 +11,10 @@ import wrapt
 from blazeutils import randchars
 from blazeutils.containers import LazyDict
 from keg import current_app
+from keg.db import db
 
 from keg_auth.libs.authenticators import AttemptLimitMixin
+from keg_auth.model.types import AttemptType
 
 has_attempt_skip_reason = 'no attempt model registered in entity registry'
 
@@ -52,7 +51,7 @@ class AuthAttemptTests(object):
         ('success', 'Password changed.  Please use the new password to login below.')
     ]
 
-    def setup(self):
+    def setup_method(self):
         if has_attempt_model:
             self.attempt_ent.delete_cascaded()
 
@@ -118,7 +117,7 @@ class AuthAttemptTests(object):
             if create_user:
                 invalid_flashes = self.login_invalid_flashes
                 success_flashes = self.login_success_flashes
-                self.user_ent.testing_create(email=username, password='pass')
+                self.user_ent.fake(email=username, password='pass')
 
             assert self.attempt_ent.query.count() == 0
 
@@ -147,7 +146,7 @@ class AuthAttemptTests(object):
             assert_attempt_count(1, 1)
             assert_attempt_count(0, 0, is_during_lockout=True)
             for i in range(0, limit - 2):
-                attempt_time = first_attempt_time + timedelta(seconds=i+1)
+                attempt_time = first_attempt_time + timedelta(seconds=i + 1)
                 do_test(attempt_time, invalid_flashes)
                 assert_attempt_count(i + 2, i + 2)
                 assert_attempt_count(0, 0, is_during_lockout=True)
@@ -190,7 +189,7 @@ class AuthAttemptTests(object):
         '''
         if not has_attempt_model():
             pytest.skip(has_attempt_skip_reason)
-        user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
+        user = self.user_ent.fake(email='foo@bar.com', password='pass')
         assert self.attempt_ent.query.count() == 0
 
         def do_test(attempt_count, flashes, password='badpass', submit_status=200):
@@ -211,7 +210,7 @@ class AuthAttemptTests(object):
         '''
         Test that we check for the registered attempt entity when limiting is enabled.
         '''
-        user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
+        user = self.user_ent.fake(email='foo@bar.com', password='pass')
         assert self.attempt_ent.query.count() == 0
 
         with pytest.raises(Exception, match=r'.*attempt entity is not registered.*'):
@@ -234,7 +233,7 @@ class AuthAttemptTests(object):
             'KEGAUTH_LOGIN_ATTEMPT_TIMESPAN': timespan,
             'KEGAUTH_LOGIN_ATTEMPT_LOCKOUT': lockout,
         }):
-            user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
+            user = self.user_ent.fake(email='foo@bar.com', password='pass')
             assert self.attempt_ent.query.count() == 0
 
             # Login and assert matching flashes and status.
@@ -304,7 +303,7 @@ class AuthAttemptTests(object):
 
             for i in range(0, limit):
                 email = randchars() + '@foo.com'
-                attempt_time = first_attempt_time + timedelta(seconds=i+1)
+                attempt_time = first_attempt_time + timedelta(seconds=i + 1)
                 do_test(email, attempt_time, invalid_flashes(email))
 
             assert_attempt_count(limit, limit)
@@ -383,7 +382,7 @@ class AuthAttemptTests(object):
             assert_attempt_count(1, 1)
             assert_attempt_count(0, 0, is_during_lockout=True)
             for i in range(0, limit - 2):
-                attempt_time = first_attempt_time + timedelta(seconds=i+1)
+                attempt_time = first_attempt_time + timedelta(seconds=i + 1)
                 do_test(attempt_time, invalid_flashes)
                 assert_attempt_count(i + 2, i + 2)
                 assert_attempt_count(0, 0, is_during_lockout=True)
@@ -468,7 +467,7 @@ class AuthAttemptTests(object):
                 do_test(attempt_time, self.forgot_invalid_flashes)
 
             # Create a successful forgot to reset the attempt counter.
-            user = self.user_ent.testing_create(email='foo@bar.com')
+            user = self.user_ent.fake(email='foo@bar.com')
             self.do_forgot_test(user.email, forgot_time, self.forgot_success_flashes,
                                 submit_status=302)
             self.user_ent.delete(user.id)
@@ -488,6 +487,7 @@ class AuthAttemptTests(object):
             'keg_auth.libs.authenticators.arrow.utcnow',
             return_value=reset_time,
         ):
+            db.session.expire(user)
             token = user.token_generate()
             url = self.reset_password_url.format(user_id=user.id, token=token)
             resp = self.client.get(url, status=200)
@@ -515,7 +515,7 @@ class AuthAttemptTests(object):
             'KEGAUTH_RESET_ATTEMPT_TIMESPAN': timespan,
             'KEGAUTH_RESET_ATTEMPT_LOCKOUT': lockout,
         }):
-            user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
+            user = self.user_ent.fake(email='foo@bar.com', password='pass')
             assert self.attempt_ent.query.count() == 0
 
             last_attempt_time = arrow.utcnow()
@@ -581,7 +581,7 @@ class AuthAttemptTests(object):
     def test_reset_pw_attempts_not_blocked(self):
         if not has_attempt_model():
             pytest.skip(has_attempt_skip_reason)
-        user = self.user_ent.testing_create()
+        user = self.user_ent.fake()
         assert self.attempt_ent.query.count() == 0
 
         def do_test(reset_time, flashes, submit_status=200):
@@ -597,11 +597,50 @@ class AuthAttemptTests(object):
     def test_logs_attempt_source_ip(self, m_get_remote_addr):
         if not has_attempt_model():
             pytest.skip(has_attempt_skip_reason)
-        user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
+        user = self.user_ent.fake(email='foo@bar.com', password='pass')
         self.do_login(self.client, user.email, 'pass', 302)
 
         assert self.attempt_ent.query.one().source_ip == m_get_remote_addr.return_value
 
+    def test_csrf_failure_logged(self):
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
+        resp = self.client.get(self.login_url)
+        resp.form['login_id'] = 'foo@bar.baz'
+        resp.form['password'] = 'notmypassword'
+        resp.form['csrf_token'] = 'foo'
+        resp.form.submit(status=400)
+
+        result = self.attempt_ent.query.one()
+        assert result.attempt_type == AttemptType.login
+        assert not result.success
+        assert result.user_input == 'foo@bar.baz'
+
+    def test_password_form_validation_failure_logged(self):
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
+        resp = self.client.get(self.login_url)
+        resp.form['login_id'] = 'myinputisnotanemail'
+        resp.form['password'] = 'notmypassword'
+        resp.form.submit(status=200)
+
+        result = self.attempt_ent.query.one()
+        assert result.attempt_type == AttemptType.login
+        assert not result.success
+        assert result.user_input == 'myinputisnotanemail'
+
+    def test_forgot_form_validation_failure_logged(self):
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
+        resp = self.client.get(self.forgot_password_url)
+        resp.form['email'] = 'myinputisnotanemail'
+        resp.form.submit(status=200)
+
+        result = self.attempt_ent.query.one()
+        assert result.attempt_type == AttemptType.forgot
+        assert not result.success
+        assert result.user_input == 'myinputisnotanemail'
+
     def test_get_request_remote_addr(self):
         if not has_attempt_model():
             pytest.skip(has_attempt_skip_reason)
@@ -623,8 +662,8 @@ class AuthTests(AuthAttemptTests):
     protected_url = '/secret1'
     protected_url_permissions = None
 
-    def setup(self):
-        super().setup()
+    def setup_method(self):
+        super().setup_method()
         self.user_ent.delete_cascaded()
 
     def test_login_get(self):
@@ -651,7 +690,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message)]
 
     def test_login_field_success(self):
-        user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
+        user = self.user_ent.fake(email='foo@bar.com', password='pass')
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get(self.login_url)
@@ -676,7 +715,7 @@ class AuthTests(AuthAttemptTests):
             )
 
     def test_login_field_success_next_parameter(self):
-        self.user_ent.testing_create(email='foo@bar.com', password='pass')
+        self.user_ent.fake(email='foo@bar.com', password='pass')
 
         next = '/foo'
         client = flask_webtest.TestApp(flask.current_app)
@@ -694,7 +733,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message)]
 
     def test_login_field_success_next_session(self):
-        self.user_ent.testing_create(email='foo@bar.com', password='pass')
+        self.user_ent.fake(email='foo@bar.com', password='pass')
 
         next = '/foo'
         with mock.patch.dict(flask.current_app.config, {'USE_SESSION_FOR_NEXT': True}):
@@ -716,7 +755,7 @@ class AuthTests(AuthAttemptTests):
 
     def test_next_parameter_not_open_redirect(self):
         """ensure following the "next" parameter doesn't allow for an open redirect"""
-        self.user_ent.testing_create(email='foo@bar.com', password='pass')
+        self.user_ent.fake(email='foo@bar.com', password='pass')
 
         # unquoted next parameter
         next = 'http://www.example.com'
@@ -752,7 +791,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message)]
 
     def test_login_invalid_password(self):
-        user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
+        user = self.user_ent.fake(email='foo@bar.com', password='pass')
         if has_attempt_model:
             assert self.attempt_ent.query.count() == 0
 
@@ -792,7 +831,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message.format('foo@bar.com'))]
 
     def test_login_user_unverified(self):
-        self.user_ent.testing_create(email='foo@bar.com', password='pass', is_verified=False)
+        self.user_ent.fake(email='foo@bar.com', password='pass', is_verified=False)
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get(self.login_url)
@@ -808,7 +847,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message.format('foo@bar.com'))]
 
     def test_login_user_disabled(self):
-        self.user_ent.testing_create(email='foo@bar.com', password='pass', is_enabled=False)
+        self.user_ent.fake(email='foo@bar.com', password='pass', is_enabled=False)
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get(self.login_url)
@@ -824,7 +863,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message.format('foo@bar.com'))]
 
     def test_login_user_disabled_timestamp(self):
-        self.user_ent.testing_create(
+        self.user_ent.fake(
             email='foo@bar.com',
             password='pass',
             disabled_utc=arrow.utcnow().shift(days=-10)
@@ -844,7 +883,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message.format('foo@bar.com'))]
 
     def test_login_protection(self):
-        self.user_ent.testing_create(
+        self.user_ent.fake(
             email='foo@bar.com', password='pass', permissions=self.protected_url_permissions
         )
 
@@ -889,7 +928,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message.format('foo@bar.com'))]
 
     def test_forgot_pw_user_disabled(self):
-        self.user_ent.testing_create(email='foo@bar.com', password='pass', is_enabled=False)
+        self.user_ent.fake(email='foo@bar.com', password='pass', is_enabled=False)
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get(self.forgot_password_url)
@@ -904,7 +943,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message.format('foo@bar.com'))]
 
     def test_forgot_pw_success(self):
-        self.user_ent.testing_create(email='foo@bar.com')
+        self.user_ent.fake(email='foo@bar.com')
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get(self.forgot_password_url)
@@ -921,7 +960,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.headers['Location'] == self.login_url
 
     def test_reset_pw_success(self):
-        user = self.user_ent.testing_create()
+        user = self.user_ent.fake()
         if has_attempt_model:
             assert self.attempt_ent.query.count() == 0
         token = user.token_generate()
@@ -946,7 +985,7 @@ class AuthTests(AuthAttemptTests):
             assert self.attempt_ent.get_by(attempt_type='reset', user_input=user.email)
 
     def test_reset_pw_form_error(self):
-        user = self.user_ent.testing_create()
+        user = self.user_ent.fake()
         token = user.token_generate()
         url = self.reset_password_url.format(user_id=user.id, token=token)
 
@@ -967,7 +1006,7 @@ class AuthTests(AuthAttemptTests):
         client.get(url, status=404)
 
     def test_reset_pw_bad_token(self):
-        user = self.user_ent.testing_create()
+        user = self.user_ent.fake()
         url = url = self.reset_password_url.format(user_id=user.id, token='abc')
 
         client = flask_webtest.TestApp(flask.current_app)
@@ -982,7 +1021,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.headers['Location'] == self.forgot_password_url
 
     def test_verify_account_success(self):
-        user = self.user_ent.testing_create(is_verified=False)
+        user = self.user_ent.fake(is_verified=False)
         assert not user.is_verified
 
         user.token_generate()
@@ -1003,10 +1042,10 @@ class AuthTests(AuthAttemptTests):
 
         assert resp.headers['Location'] == self.login_url
 
-        assert user.is_verified
+        assert self.user_ent.query.filter_by(id=user.id, is_verified=True).count() == 1
 
     def test_verify_account_form_error(self):
-        user = self.user_ent.testing_create()
+        user = self.user_ent.fake()
         user.token_generate()
         url = flask.current_app.auth_manager.mail_manager.verify_account_url(user)
 
@@ -1028,7 +1067,7 @@ class AuthTests(AuthAttemptTests):
         client.get(url, status=404)
 
     def test_verify_account_bad_token(self):
-        user = self.user_ent.testing_create()
+        user = self.user_ent.fake()
         user._token_plain = 'abc'
         url = flask.current_app.auth_manager.mail_manager.verify_account_url(user)
 
@@ -1044,7 +1083,7 @@ class AuthTests(AuthAttemptTests):
         assert resp.headers['Location'] == self.forgot_password_url
 
     def test_logout(self):
-        user = self.user_ent.testing_create(permissions=self.protected_url_permissions)
+        user = self.user_ent.fake(permissions=self.protected_url_permissions)
         client = flask_webtest.TestApp(flask.current_app)
         with client.session_transaction() as sess:
             sess['_user_id'] = user.session_key
@@ -1063,7 +1102,7 @@ class AuthTests(AuthAttemptTests):
         client.get(self.protected_url, status=302)
 
     def test_list_user(self):
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/users?op(username)=eq&v1(username)=' + user.email)
         assert resp.pyquery('.grid-header-add-link a').attr('href').startswith('/users/add')
@@ -1071,8 +1110,8 @@ class AuthTests(AuthAttemptTests):
         assert resp.pyquery('.grid-header-add-link').eq(0).text() == 'Create User'
 
     def test_edit_user(self):
-        user_edit = self.user_ent.testing_create()
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        user_edit = self.user_ent.fake()
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/users/{}/edit'.format(user_edit.id))
         assert resp.pyquery('h1').eq(0).text() == 'Edit User'
@@ -1083,8 +1122,8 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [('success', 'Successfully modified User')]
 
     def test_delete_user(self):
-        user_delete_id = self.user_ent.testing_create().id
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        user_delete_id = self.user_ent.fake().id
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/users/{}/delete'.format(user_delete_id))
 
@@ -1095,16 +1134,16 @@ class AuthTests(AuthAttemptTests):
         assert not self.user_ent.query.get(user_delete_id)
 
     def test_list_group(self):
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
-        group = self.group_ent.testing_create()
+        group = self.group_ent.fake()
         resp = client.get('/groups?op(name)=eq&v1(name)=' + group.name)
         assert resp.pyquery('.grid-header-add-link a').attr('href').startswith('/groups/add')
         assert resp.pyquery('h1').eq(0).text() == 'Groups'
         assert resp.pyquery('.grid-header-add-link').eq(0).text() == 'Create Group'
 
     def test_add_group(self):
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/groups/add')
         group_name = randchars()
@@ -1117,9 +1156,9 @@ class AuthTests(AuthAttemptTests):
         assert self.group_ent.get_by(name=group_name)
 
     def test_edit_group(self):
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
-        group = self.group_ent.testing_create()
+        group = self.group_ent.fake()
         resp = client.get(f'/groups/{group.id}/edit')
         resp = resp.form.submit()
         assert resp.status_code == 302
@@ -1127,8 +1166,8 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [('success', 'Successfully modified Group')]
 
     def test_delete_group(self):
-        group_delete_id = self.group_ent.testing_create().id
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        group_delete_id = self.group_ent.fake().id
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get(f'/groups/{group_delete_id}/delete')
 
@@ -1139,16 +1178,16 @@ class AuthTests(AuthAttemptTests):
         assert not self.group_ent.query.get(group_delete_id)
 
     def test_list_bundle(self):
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
-        bundle = self.bundle_ent.testing_create()
+        bundle = self.bundle_ent.fake()
         resp = client.get('/bundles?op(name)=eq&v1(name)=' + bundle.name)
         assert resp.pyquery('.grid-header-add-link a').attr('href').startswith('/bundles/add')
         assert resp.pyquery('h1').eq(0).text() == 'Bundles'
         assert resp.pyquery('.grid-header-add-link').eq(0).text() == 'Create Bundle'
 
     def test_add_bundle(self):
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/bundles/add')
         bundle_name = randchars()
@@ -1161,9 +1200,9 @@ class AuthTests(AuthAttemptTests):
         assert self.bundle_ent.get_by(name=bundle_name)
 
     def test_edit_bundle(self):
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
-        bundle = self.bundle_ent.testing_create()
+        bundle = self.bundle_ent.fake()
         resp = client.get(f'/bundles/{bundle.id}/edit')
         resp = resp.form.submit()
         assert resp.status_code == 302
@@ -1171,8 +1210,8 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [('success', 'Successfully modified Bundle')]
 
     def test_delete_bundle(self):
-        bundle_delete_id = self.bundle_ent.testing_create().id
-        user = self.user_ent.testing_create(permissions=['auth-manage'])
+        bundle_delete_id = self.bundle_ent.fake().id
+        user = self.user_ent.fake(permissions=['auth-manage'])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get(f'/bundles/{bundle_delete_id}/delete')
 
@@ -1204,7 +1243,7 @@ def with_crypto_context(field, context=None):
     .. NOTE:
 
     In most situations we don't want a real crypto scheme to run in the tests, it is
-    slow on entities like Users which have a password. ``User.testing_create`` will generate a value
+    slow on entities like Users which have a password. ``User.fake`` will generate a value
     for that instance and then hash which takes a bunch of time. However, when testing certain
     schemes, it is useful to execute the real behavior instead of the ``plaintext`` behaviour.
 
@@ -1216,7 +1255,7 @@ def with_crypto_context(field, context=None):
 
         @with_crypto_context(ents.User.password, context=bcrypt_context)
         def test_with_real_context():
-            user = ents.User.testing_create(password='abc')
+            user = ents.User.fake(password='abc')
             assert bcrypt.checkpw('abc', user.password.hash)
 
     """
@@ -1241,7 +1280,7 @@ class AuthTestApp(flask_webtest.TestApp):
 
     Pass in a user instance to "log in" the session:
 
-        user = User.testing_create(permissions=['auth-manage', 'do-something'])
+        user = User.fake(permissions=['auth-manage', 'do-something'])
         test_app = AuthTestApp(flask.current_app, user=user)
 
     When running integration tests, following the view sequence to log a user in can
@@ -1317,9 +1356,9 @@ class ViewTestBase:
 
     @classmethod
     def create_user(cls):
-        """ Creates a User record for tests. By default, simply calls ``testing_create`` with
+        """ Creates a User record for tests. By default, simply calls ``fake`` with
             permissions."""
-        return cls.user_ent.testing_create(permissions=cls.permissions)
+        return cls.user_ent.fake(permissions=cls.permissions)
 
     @classmethod
     def setup_user(cls):
