@@ -1,6 +1,3 @@
-# Using unicode_literals instead of adding 'u' prefix to all stings that go to SA.
-from __future__ import unicode_literals
-
 import sys
 from unittest import mock
 
@@ -66,7 +63,7 @@ class TestNavItem(object):
         Tests of node permissions are user-oriented, so we have to run these in a request context
     """
 
-    def setup(self):
+    def setup_method(self):
         self.Permission = flask.current_app.auth_manager.entity_registry.permission_cls
         self.Permission.delete_cascaded()
 
@@ -155,7 +152,7 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert node.is_permitted
@@ -167,7 +164,7 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert node.is_permitted
@@ -180,7 +177,7 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert node.is_permitted
@@ -192,14 +189,14 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
 
-            perm1 = self.Permission.testing_create(token='permission1')
-            perm2 = self.Permission.testing_create(token='permission2')
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            perm1 = self.Permission.fake(token='permission1')
+            perm2 = self.Permission.fake(token='permission2')
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm1, perm2])
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
@@ -212,7 +209,7 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
@@ -229,14 +226,14 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
 
-            perm1 = self.Permission.testing_create(token='permission1')
-            perm2 = self.Permission.testing_create(token='permission2')
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            perm1 = self.Permission.fake(token='permission1')
+            perm2 = self.Permission.fake(token='permission2')
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm1, perm2])
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
@@ -249,7 +246,7 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
@@ -267,26 +264,26 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
 
-            perm1 = self.Permission.testing_create(token='permission1')
-            perm2 = self.Permission.testing_create(token='permission2')
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            perm1 = self.Permission.fake(token='permission1')
+            perm2 = self.Permission.fake(token='permission2')
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm1])
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm2])
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm1, perm2])
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
@@ -299,13 +296,13 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
 
-            perm1 = self.Permission.testing_create(token='permission1')
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            perm1 = self.Permission.fake(token='permission1')
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm1])
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
@@ -318,13 +315,13 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
 
-            perm1 = self.Permission.testing_create(token='permission1')
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            perm1 = self.Permission.fake(token='permission1')
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm1])
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
@@ -337,13 +334,13 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
 
-            perm1 = self.Permission.testing_create(token='permission1')
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            perm1 = self.Permission.fake(token='permission1')
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm1])
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
@@ -356,7 +353,7 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert node.is_permitted
@@ -368,13 +365,13 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert node.is_permitted
 
     def test_permitted_subnodes(self):
-        perm1 = self.Permission.testing_create(token='permission1')
+        perm1 = self.Permission.fake(token='permission1')
         node = NavItem(
             'Menu',
             NavItem('Index', NavURL('public.home', requires_permissions='permission2')),
@@ -390,7 +387,7 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.permitted_sub_nodes
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm1])
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
@@ -408,12 +405,12 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             assert not node.is_permitted
 
-            perm1 = self.Permission.testing_create(token='permission1')
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create(
+            perm1 = self.Permission.fake(token='permission1')
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake(
                 permissions=[perm1])
             flask_login.login_user(user)
             assert node.is_permitted
@@ -432,7 +429,7 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert not node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert node.is_permitted
@@ -444,7 +441,7 @@ class TestNavItem(object):
             flask_login.logout_user()
             assert node.is_permitted
 
-            user = flask.current_app.auth_manager.entity_registry.user_cls.testing_create()
+            user = flask.current_app.auth_manager.entity_registry.user_cls.fake()
             flask_login.login_user(user)
             node.clear_authorization(user.get_id())
             assert not node.is_permitted
