@@ -1,6 +1,5 @@
 from unittest import mock
 
-from blazeutils.datastructures import BlankObject
 import flask
 import freezegun
 import arrow
@@ -37,11 +36,11 @@ class TestViews(object):
     @classmethod
     def setup_class(cls):
         ents.Permission.delete_cascaded()
-        cls.perm1 = ents.Permission.testing_create(token='permission1')
-        cls.perm2 = ents.Permission.testing_create(token='permission2')
-        cls.perm_auth = ents.Permission.testing_create(token='auth-manage')
+        cls.perm1 = ents.Permission.fake(token='permission1')
+        cls.perm2 = ents.Permission.fake(token='permission2')
+        cls.perm_auth = ents.Permission.fake(token='auth-manage')
 
-    def setup(self):
+    def setup_method(self):
         ents.User.delete_cascaded()
 
     def test_class_decorator_throws_exception(self):
@@ -57,7 +56,7 @@ class TestViews(object):
         assert '/login' in resp
         assert '/logout' not in resp
 
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         with client.session_transaction() as sess:
             sess['_user_id'] = user.session_key
 
@@ -66,8 +65,8 @@ class TestViews(object):
         assert '/logout' in resp
 
     def test_auth_base_view(self):
-        ents.User.testing_create(email='foo@bar.com', password='pass',
-                                 permissions=[self.perm1, self.perm2])
+        ents.User.fake(email='foo@bar.com', password='pass',
+                       permissions=[self.perm1, self.perm2])
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get('/secret2', status=302)
@@ -83,8 +82,8 @@ class TestViews(object):
         assert resp.text == 'secret2'
 
     def test_rendered_navigation(self):
-        ents.User.testing_create(email='foo@bar.com', password='pass',
-                                 permissions=[self.perm_auth])
+        ents.User.fake(email='foo@bar.com', password='pass',
+                       permissions=[self.perm_auth])
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get('/')
@@ -112,7 +111,7 @@ class TestViews(object):
         assert not doc.find('div#navigation a[href="/secret-nested"]')
 
     def test_navigation_group(self):
-        user = ents.User.testing_create(permissions=[self.perm_auth])
+        user = ents.User.fake(permissions=[self.perm_auth])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/')
         nav_el = resp.pyquery('#navigation')
@@ -133,21 +132,21 @@ class TestViews(object):
             assert nav_el('[href="#navgroup-auth"]').attr('aria-expanded') != 'true'
 
     def test_navigation_group_class(self):
-        user = ents.User.testing_create(permissions=[self.perm_auth, self.perm1, self.perm2])
+        user = ents.User.fake(permissions=[self.perm_auth, self.perm1, self.perm2])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/')
         nav_el = resp.pyquery('#navigation')
         assert nav_el('.group-header.my-group-class').text() == 'Sub-Menu'
 
     def test_navigation_link_class(self):
-        user = ents.User.testing_create(permissions=[self.perm_auth, self.perm1, self.perm2])
+        user = ents.User.fake(permissions=[self.perm_auth, self.perm1, self.perm2])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/')
         nav_el = resp.pyquery('#navigation')
         assert nav_el('.my-link-class').text() == 'Secret View'
 
     def test_navigation_icon(self):
-        user = ents.User.testing_create(permissions=[self.perm_auth])
+        user = ents.User.fake(permissions=[self.perm_auth])
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/')
         nav_el = resp.pyquery('#navigation')
@@ -157,7 +156,7 @@ class TestViews(object):
         assert len(nav_el('i.fas.fa-ad')) == 1
 
     def test_authenticated_client(self):
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         client = AuthTestApp(flask.current_app, user=user)
         resp = client.get('/secret1', status=200)
         assert resp.text == 'secret1'
@@ -179,7 +178,7 @@ class TestViews(object):
 
     @freezegun.freeze_time("2018-10-01 15:00:00")
     def test_login_user_sets_last_login_and_invalidates_token(self):
-        u = ents.User.testing_create(email='foo@bar.com', password='pass', last_login_utc=None)
+        u = ents.User.fake(email='foo@bar.com', password='pass', last_login_utc=None)
         token = u.token_generate()
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get('/login', status=200)
@@ -197,7 +196,7 @@ class TestViews(object):
         assert not u.token_verify(token)
 
     def test_login_field_success_next_parameter(self):
-        ents.User.testing_create(email='foo@bar.com', password='pass')
+        ents.User.fake(email='foo@bar.com', password='pass')
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get('/secret1', status=302).follow()
@@ -211,7 +210,7 @@ class TestViews(object):
         assert resp.flashes == [('success', 'Login successful.')]
 
     def test_login_field_success_next_session(self):
-        ents.User.testing_create(email='foo@bar.com', password='pass')
+        ents.User.fake(email='foo@bar.com', password='pass')
 
         with mock.patch.dict(flask.current_app.config, {'USE_SESSION_FOR_NEXT': True}):
             client = flask_webtest.TestApp(flask.current_app)
@@ -226,7 +225,7 @@ class TestViews(object):
         assert resp.flashes == [('success', 'Login successful.')]
 
     def test_authenticated_request(self):
-        user = ents.User.testing_create(permissions=[self.perm1, self.perm2])
+        user = ents.User.fake(permissions=[self.perm1, self.perm2])
         client = AuthTestApp(flask.current_app)
 
         resp = client.get('/secret2', status=200, user=user)
@@ -288,7 +287,7 @@ class TestViews(object):
     @mock.patch('keg_auth.views.flask.current_app.auth_manager.mail_manager.send_reset_password',
                 autospec=True, spec_set=True)
     def test_forget_pw_actions(self, m_send_reset_password):
-        user = ents.User.testing_create(email='foo@bar.com')
+        user = ents.User.fake(email='foo@bar.com')
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get('/forgot-password')
@@ -304,7 +303,7 @@ class TestViews(object):
         client.get('/forgot-password', status=404)
 
     def test_reset_pw_template(self):
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         user.token_generate()
         url = flask.current_app.auth_manager.mail_manager.reset_password_url(user)
 
@@ -318,14 +317,14 @@ class TestViews(object):
         assert doc('div#page-content a').attr('href') == '/login'
 
     def test_reset_pw_head(self):
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         token = user.token_generate()
 
         client = flask_webtest.TestApp(flask.current_app)
         client.head('/reset-password/{}/{}'.format(user.id, token), status=405)
 
     def test_reset_pw_actions(self):
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         token = user.token_generate()
 
         client = flask_webtest.TestApp(flask.current_app)
@@ -339,14 +338,14 @@ class TestViews(object):
 
     @mock.patch('flask.current_app.auth_manager.mail_manager', None)
     def test_reset_pw_actions_mail_disabled(self):
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         token = user.token_generate()
 
         client = flask_webtest.TestApp(flask.current_app)
         client.get('/reset-password/{}/{}'.format(user.id, token), status=404)
 
     def test_verify_account_template(self):
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         user.token_generate()
         url = flask.current_app.auth_manager.mail_manager.verify_account_url(user)
 
@@ -364,12 +363,12 @@ class TestPermissionsRequired:
     @classmethod
     def setup_class(cls):
         ents.Permission.delete_cascaded()
-        cls.perm1 = ents.Permission.testing_create(token='permission1')
-        cls.perm2 = ents.Permission.testing_create(token='permission2')
-        cls.perm3 = ents.Permission.testing_create(token='permission3')
+        cls.perm1 = ents.Permission.fake(token='permission1')
+        cls.perm2 = ents.Permission.fake(token='permission2')
+        cls.perm3 = ents.Permission.fake(token='permission3')
 
     def test_custom_authentication_failure(self):
-        allowed = ents.User.testing_create()
+        allowed = ents.User.fake()
         client = AuthTestApp(flask.current_app, user=allowed)
         resp = client.get('/custom-auth-failure', status=200)
         assert resp.text == 'custom-auth-failure'
@@ -378,8 +377,8 @@ class TestPermissionsRequired:
         client.get('/custom-auth-failure', status=400)
 
     def test_custom_authorization_failure(self):
-        allowed = ents.User.testing_create(permissions=[self.perm1])
-        disallowed = ents.User.testing_create()
+        allowed = ents.User.fake(permissions=[self.perm1])
+        disallowed = ents.User.fake()
         client = AuthTestApp(flask.current_app, user=allowed)
         resp = client.get('/custom-perm-failure', status=200)
         assert resp.text == 'custom-perm-failure'
@@ -388,8 +387,8 @@ class TestPermissionsRequired:
         client.get('/custom-perm-failure', status=400)
 
     def test_method_level(self):
-        allowed = ents.User.testing_create(permissions=[self.perm1, self.perm2])
-        disallowed = ents.User.testing_create(permissions=[self.perm1])
+        allowed = ents.User.fake(permissions=[self.perm1, self.perm2])
+        disallowed = ents.User.fake(permissions=[self.perm1])
 
         client = AuthTestApp(flask.current_app, user=allowed)
         resp = client.get('/secret2', status=200)
@@ -400,8 +399,8 @@ class TestPermissionsRequired:
 
     @pytest.mark.parametrize('endpoint', ['secret3', 'secret-flask'])
     def test_class_level(self, endpoint):
-        allowed = ents.User.testing_create(permissions=[self.perm1, self.perm2])
-        disallowed = ents.User.testing_create(permissions=[self.perm1])
+        allowed = ents.User.fake(permissions=[self.perm1, self.perm2])
+        disallowed = ents.User.fake(permissions=[self.perm1])
 
         client = AuthTestApp(flask.current_app, user=allowed)
         resp = client.get('/{}'.format(endpoint), status=200)
@@ -415,8 +414,8 @@ class TestPermissionsRequired:
 
     @pytest.mark.parametrize('endpoint', ['secret3-sub', 'secret-flask-sub'])
     def test_class_level_inheritance(self, endpoint):
-        allowed = ents.User.testing_create(permissions=[self.perm1, self.perm2])
-        disallowed = ents.User.testing_create(permissions=[self.perm1])
+        allowed = ents.User.fake(permissions=[self.perm1, self.perm2])
+        disallowed = ents.User.fake(permissions=[self.perm1])
 
         client = AuthTestApp(flask.current_app, user=allowed)
         resp = client.get('/{}'.format(endpoint), status=200)
@@ -430,9 +429,9 @@ class TestPermissionsRequired:
 
     @pytest.mark.parametrize('endpoint', ['secret4', 'secret-flask4'])
     def test_class_and_method_level_combined(self, endpoint):
-        allowed = ents.User.testing_create(permissions=[self.perm1, self.perm2])
-        disallowed1 = ents.User.testing_create(permissions=[self.perm1])
-        disallowed2 = ents.User.testing_create(permissions=[self.perm2])
+        allowed = ents.User.fake(permissions=[self.perm1, self.perm2])
+        disallowed1 = ents.User.fake(permissions=[self.perm1])
+        disallowed2 = ents.User.fake(permissions=[self.perm2])
 
         client = AuthTestApp(flask.current_app, user=allowed)
         resp = client.get('/{}'.format(endpoint), status=200)
@@ -453,7 +452,7 @@ class TestPermissionsRequired:
         def check(perms, allowed):
             print(perms, allowed)
             target_status = 200 if allowed else 403
-            user = ents.User.testing_create(permissions=perms)
+            user = ents.User.fake(permissions=perms)
 
             client = AuthTestApp(flask.current_app, user=user)
             resp = client.get('/secret-nested', status=target_status)
@@ -474,7 +473,7 @@ class TestPermissionsRequired:
             print(perms, email, allowed)
             ents.User.delete_cascaded()
             target_status = 200 if allowed else 403
-            user = ents.User.testing_create(permissions=perms, email=email)
+            user = ents.User.fake(permissions=perms, email=email)
 
             client = AuthTestApp(flask.current_app, user=user)
             resp = client.get('/secret-nested-callable', status=target_status)
@@ -493,7 +492,7 @@ class TestPermissionsRequired:
             print(email, allowed)
             ents.User.delete_cascaded()
             target_status = 200 if allowed else 403
-            user = ents.User.testing_create(email=email)
+            user = ents.User.fake(email=email)
 
             client = AuthTestApp(flask.current_app, user=user)
             resp = client.get('/secret-callable', status=target_status)
@@ -507,8 +506,8 @@ class TestPermissionsRequired:
             check(email, allowed)
 
     def test_blueprint_method_level(self):
-        allowed = ents.User.testing_create(permissions=[self.perm1])
-        disallowed = ents.User.testing_create()
+        allowed = ents.User.fake(permissions=[self.perm1])
+        disallowed = ents.User.fake()
 
         client = AuthTestApp(flask.current_app, user=allowed)
         resp = client.get('/protected-method', status=200)
@@ -518,8 +517,8 @@ class TestPermissionsRequired:
         client.get('/protected-method', status=403)
 
     def test_blueprint_class_level(self):
-        allowed = ents.User.testing_create(permissions=[self.perm1])
-        disallowed = ents.User.testing_create()
+        allowed = ents.User.fake(permissions=[self.perm1])
+        disallowed = ents.User.fake()
 
         client = AuthTestApp(flask.current_app, user=allowed)
         resp = client.get('/protected-class', status=200)
@@ -548,7 +547,7 @@ class TestRequestLoaders(object):
         client.get('/jwt-required', status=302)
 
     def test_token_auth_with_token(self):
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         jwt_auth = flask.current_app.auth_manager.get_request_loader('jwt')
         token = jwt_auth.create_access_token(user)
 
@@ -562,12 +561,12 @@ class TestUserCrud(ViewTestBase):
     permissions = 'auth-manage'
 
     def test_add(self):
-        perm_approve = ents.Permission.testing_create()
-        ents.Permission.testing_create()
-        group_approve = ents.Group.testing_create()
-        ents.Group.testing_create()
-        bundle_approve = ents.Bundle.testing_create()
-        ents.Bundle.testing_create()
+        perm_approve = ents.Permission.fake()
+        ents.Permission.fake()
+        group_approve = ents.Group.fake()
+        ents.Group.fake()
+        bundle_approve = ents.Bundle.fake()
+        ents.Bundle.fake()
 
         resp = self.client.get('/users/add')
 
@@ -613,7 +612,7 @@ class TestUserCrud(ViewTestBase):
         self.current_user.permissions = ents.Permission.query.filter_by(token='auth-manage').all()
         for user in ents.User.query.filter(ents.User.email != self.current_user.email):
             ents.db.session.delete(user)
-        user_edit = self.user_ent.testing_create(
+        user_edit = self.user_ent.fake(
             is_verified=False,
             email="foo1@bar.com",
             is_superuser=False,
@@ -646,12 +645,12 @@ class TestUserCrud(ViewTestBase):
             assert resp.pyquery('.datagrid table.records thead th').eq(4).text() == ''
 
     def test_add_and_token_is_correct(self):
-        perm_approve = ents.Permission.testing_create()
-        ents.Permission.testing_create()
-        group_approve = ents.Group.testing_create()
-        ents.Group.testing_create()
-        bundle_approve = ents.Bundle.testing_create()
-        ents.Bundle.testing_create()
+        perm_approve = ents.Permission.fake()
+        ents.Permission.fake()
+        group_approve = ents.Group.fake()
+        ents.Group.fake()
+        bundle_approve = ents.Bundle.fake()
+        ents.Bundle.fake()
 
         resp = self.client.get('/users/add')
 
@@ -711,7 +710,7 @@ class TestUserCrud(ViewTestBase):
 
     @mock.patch.dict('flask.current_app.config', {'KEGAUTH_EMAIL_OPS_ENABLED': False})
     def test_edit_no_email_same_password(self):
-        user = self.user_ent.testing_create()
+        user = self.user_ent.fake()
         resp = self.client.get('/users/{}/edit'.format(user.id))
 
         resp = resp.form.submit()
@@ -730,7 +729,7 @@ class TestUserCrud(ViewTestBase):
 
     @mock.patch.dict('flask.current_app.config', {'KEGAUTH_EMAIL_OPS_ENABLED': False})
     def test_edit_no_email_reset_password(self):
-        user = self.user_ent.testing_create(password='foobar')
+        user = self.user_ent.fake(password='foobar')
         resp = self.client.get('/users/{}/edit'.format(user.id))
 
         resp.form['reset_password'] = 'bleh'
@@ -766,10 +765,10 @@ class TestUserCrud(ViewTestBase):
         assert 'a_template_variable' in m_render.call_args[1]
 
     def test_edit(self):
-        user_edit = ents.User.testing_create(
-            groups=[ents.Group.testing_create()],
-            bundles=[ents.Bundle.testing_create()],
-            permissions=[ents.Permission.testing_create()],
+        user_edit = ents.User.fake(
+            groups=[ents.Group.fake()],
+            bundles=[ents.Bundle.fake()],
+            permissions=[ents.Permission.fake()],
         )
 
         resp = self.client.get('/users/{}/edit'.format(user_edit.id))
@@ -794,12 +793,12 @@ class TestUserCrud(ViewTestBase):
         assert self.user_ent.get_by(email='foo@bar.baz')
 
     def test_edit_disallowed_by_permission(self):
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         client = AuthTestApp(flask.current_app, user=user)
         client.get('/users/99999/edit', status=403)
 
     def test_edit_with_session_key(self):
-        user_edit = ents.User.testing_create()
+        user_edit = ents.User.fake()
 
         resp = self.client.get('/users/{}/edit?session_key=foo'.format(user_edit.id))
         assert resp.pyquery('a.cancel').attr('href').endswith('/users?session_key=foo')
@@ -809,9 +808,9 @@ class TestUserCrud(ViewTestBase):
         assert resp.location.endswith('/users?session_key=foo')
 
     def test_edit_triggers_user_session_key_refresh(self):
-        target_user = ents.User.testing_create(permissions='auth-manage')
+        target_user = ents.User.fake(permissions='auth-manage')
         target_user_client = AuthTestApp(flask.current_app, user=target_user)
-        new_perm = ents.Permission.testing_create()
+        new_perm = ents.Permission.fake()
         original_session_key = target_user.session_key
 
         # target user has matching session key and rights to page
@@ -837,10 +836,10 @@ class TestUserCrud(ViewTestBase):
     def test_alternate_permissions(self, action):
         # patch in separate permissions for add/edit/view/delete
         actions = {'add', 'edit', 'delete', 'list'}
-        ents.Permission.testing_create(token='permission1')
+        ents.Permission.fake(token='permission1')
 
-        user_edit = ents.User.testing_create()
-        user_delete = ents.User.testing_create()
+        user_edit = ents.User.fake()
+        user_delete = ents.User.fake()
 
         def url(url_action):
             if url_action == 'list':
@@ -857,19 +856,19 @@ class TestUserCrud(ViewTestBase):
             ].view_class.permissions,
             {action: 'permission1'}
         ):
-            user = ents.User.testing_create(permissions='auth-manage')
+            user = ents.User.fake(permissions='auth-manage')
             client = AuthTestApp(flask.current_app, user=user)
             client.get(url(action), status=403)
             for url_action in actions.difference({action}):
                 print(url_action, url(url_action))
                 client.get(url(url_action))
 
-            user = ents.User.testing_create(permissions=('auth-manage', 'permission1'))
+            user = ents.User.fake(permissions=('auth-manage', 'permission1'))
             client = AuthTestApp(flask.current_app, user=user)
             client.get(url(action))
 
     def test_delete(self):
-        user_delete_id = ents.User.testing_create().id
+        user_delete_id = ents.User.fake().id
 
         resp = self.client.get('/users/{}/delete'.format(user_delete_id))
 
@@ -880,7 +879,7 @@ class TestUserCrud(ViewTestBase):
         assert not self.user_ent.query.get(user_delete_id)
 
     def test_delete_disallowed_by_action_init(self):
-        user_delete_id = ents.User.testing_create().id
+        user_delete_id = ents.User.fake().id
 
         def init_object_delete(self):
             flask.abort(403)
@@ -896,12 +895,12 @@ class TestUserCrud(ViewTestBase):
         self.client.get('/users/{}/delete'.format(user_delete_id), status=302)
 
     def test_delete_disallowed_by_permission(self):
-        user = ents.User.testing_create()
+        user = ents.User.fake()
         client = AuthTestApp(flask.current_app, user=user)
         client.get('/users/99999/delete', status=403)
 
     def test_delete_with_session_key(self):
-        user_delete = ents.User.testing_create()
+        user_delete = ents.User.fake()
 
         resp = self.client.get('/users/{}/delete?session_key=foo'.format(user_delete.id))
 
@@ -919,7 +918,7 @@ class TestUserCrud(ViewTestBase):
     @mock.patch('keg_elements.db.mixins.db.session.delete', autospec=True, spec_set=True)
     def test_delete_failed(self, m_delete):
         m_delete.side_effect = sa.exc.IntegrityError(None, None, None)
-        user_delete_id = ents.User.testing_create().id
+        user_delete_id = ents.User.fake().id
 
         resp = self.client.get('/users/{}/delete'.format(user_delete_id))
 
@@ -948,7 +947,7 @@ class TestUserCrud(ViewTestBase):
         # with the mock here, authentication/authorization will also be happening on the alternate
         # class, which doesn't have relationships like permissions. So, to make this easy, make it
         # a superuser.
-        user = ents.UserNoEmail.testing_create(is_superuser=True)
+        user = ents.UserNoEmail.fake(is_superuser=True)
         client = AuthTestApp(flask.current_app, user=user)
         with mock.patch('keg_auth_ta.extensions.auth_entity_registry._user_cls', ents.UserNoEmail):
             resp = client.get('/users?op(username)=eq&v1(username)=' + user.username)
@@ -970,7 +969,7 @@ class TestUserCrud(ViewTestBase):
         self.client.post('/users', status=400)
 
     def test_list_export(self):
-        ents.User.testing_create()
+        ents.User.fake()
         resp = self.client.get('/users?export_to=xlsx')
         assert resp.content_type == 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'  # noqa
 
@@ -979,10 +978,10 @@ class TestGroupCrud(ViewTestBase):
     permissions = 'auth-manage'
 
     def test_add(self):
-        perm_approve = ents.Permission.testing_create()
-        ents.Permission.testing_create()
-        bundle_approve = ents.Bundle.testing_create()
-        ents.Bundle.testing_create()
+        perm_approve = ents.Permission.fake()
+        ents.Permission.fake()
+        bundle_approve = ents.Bundle.fake()
+        ents.Bundle.fake()
 
         resp = self.client.get('/groups/add')
 
@@ -1002,8 +1001,8 @@ class TestGroupCrud(ViewTestBase):
         assert group.bundles == [bundle_approve]
 
     def test_edit(self):
-        group_edit = ents.Group.testing_create(bundles=[ents.Bundle.testing_create()],
-                                               permissions=[ents.Permission.testing_create()])
+        group_edit = ents.Group.fake(bundles=[ents.Bundle.fake()],
+                                     permissions=[ents.Permission.fake()])
 
         resp = self.client.get('/groups/{}/edit'.format(group_edit.id))
         assert resp.form['name'].value == group_edit.name
@@ -1034,10 +1033,10 @@ class TestGroupCrud(ViewTestBase):
     def test_alternate_permissions(self, action):
         # patch in separate permissions for add/edit/view/delete
         actions = {'add', 'edit', 'delete', 'list'}
-        ents.Permission.testing_create(token='permission1')
+        ents.Permission.fake(token='permission1')
 
-        group_edit = ents.Group.testing_create()
-        group_delete = ents.Group.testing_create()
+        group_edit = ents.Group.fake()
+        group_delete = ents.Group.fake()
 
         def url(url_action):
             if url_action == 'list':
@@ -1054,19 +1053,19 @@ class TestGroupCrud(ViewTestBase):
             ].view_class.permissions,
             {action: 'permission1'}
         ):
-            user = ents.User.testing_create(permissions='auth-manage')
+            user = ents.User.fake(permissions='auth-manage')
             client = AuthTestApp(flask.current_app, user=user)
             client.get(url(action), status=403)
             for url_action in actions.difference({action}):
                 print(url_action, url(url_action))
                 client.get(url(url_action))
 
-            user = ents.User.testing_create(permissions=('auth-manage', 'permission1'))
+            user = ents.User.fake(permissions=('auth-manage', 'permission1'))
             client = AuthTestApp(flask.current_app, user=user)
             client.get(url(action))
 
     def test_delete(self):
-        group_delete_id = ents.Group.testing_create().id
+        group_delete_id = ents.Group.fake().id
 
         resp = self.client.get('/groups/{}/delete'.format(group_delete_id))
 
@@ -1079,7 +1078,7 @@ class TestGroupCrud(ViewTestBase):
     @mock.patch('keg_elements.db.mixins.db.session.delete', autospec=True, spec_set=True)
     def test_delete_failed(self, m_delete):
         m_delete.side_effect = sa.exc.IntegrityError(None, None, None)
-        group_delete_id = ents.Group.testing_create().id
+        group_delete_id = ents.Group.fake().id
 
         resp = self.client.get('/groups/{}/delete'.format(group_delete_id))
 
@@ -1091,13 +1090,13 @@ class TestGroupCrud(ViewTestBase):
         assert ents.Group.query.get(group_delete_id)
 
     def test_list(self):
-        ents.Group.testing_create()
+        ents.Group.fake()
         resp = self.client.get('/groups')
         assert resp.pyquery('.grid-header-add-link a').attr('href').startswith('/groups/add')
         assert 'datagrid' in resp
 
     def test_list_export(self):
-        ents.Group.testing_create()
+        ents.Group.fake()
         resp = self.client.get('/groups?export_to=xlsx')
         assert resp.content_type == 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'  # noqa
 
@@ -1112,8 +1111,8 @@ class TestBundleCrud(ViewTestBase):
         ents.Bundle.delete_cascaded()
 
     def test_add(self):
-        perm_approve = ents.Permission.testing_create()
-        ents.Permission.testing_create()
+        perm_approve = ents.Permission.fake()
+        ents.Permission.fake()
 
         resp = self.client.get('/bundles/add')
 
@@ -1131,7 +1130,7 @@ class TestBundleCrud(ViewTestBase):
         assert bundle.permissions == [perm_approve]
 
     def test_edit(self):
-        bundle_edit = ents.Bundle.testing_create(permissions=[ents.Permission.testing_create()])
+        bundle_edit = ents.Bundle.fake(permissions=[ents.Permission.fake()])
 
         resp = self.client.get('/bundles/{}/edit'.format(bundle_edit.id))
         assert resp.form['name'].value == bundle_edit.name
@@ -1161,10 +1160,10 @@ class TestBundleCrud(ViewTestBase):
     def test_alternate_permissions(self, action):
         # patch in separate permissions for add/edit/view/delete
         actions = {'add', 'edit', 'delete', 'list'}
-        ents.Permission.testing_create(token='permission1')
+        ents.Permission.fake(token='permission1')
 
-        bundle_edit = ents.Bundle.testing_create()
-        bundle_delete = ents.Bundle.testing_create()
+        bundle_edit = ents.Bundle.fake()
+        bundle_delete = ents.Bundle.fake()
 
         def url(url_action):
             if url_action == 'list':
@@ -1181,19 +1180,19 @@ class TestBundleCrud(ViewTestBase):
             ].view_class.permissions,
             {action: 'permission1'}
         ):
-            user = ents.User.testing_create(permissions='auth-manage')
+            user = ents.User.fake(permissions='auth-manage')
             client = AuthTestApp(flask.current_app, user=user)
             client.get(url(action), status=403)
             for url_action in actions.difference({action}):
                 print(url_action, url(url_action))
                 client.get(url(url_action))
 
-            user = ents.User.testing_create(permissions=('auth-manage', 'permission1'))
+            user = ents.User.fake(permissions=('auth-manage', 'permission1'))
             client = AuthTestApp(flask.current_app, user=user)
             client.get(url(action))
 
     def test_delete(self):
-        bundle_delete_id = ents.Bundle.testing_create().id
+        bundle_delete_id = ents.Bundle.fake().id
 
         resp = self.client.get('/bundles/{}/delete'.format(bundle_delete_id))
 
@@ -1206,7 +1205,7 @@ class TestBundleCrud(ViewTestBase):
     @mock.patch('keg_elements.db.mixins.db.session.delete', autospec=True, spec_set=True)
     def test_delete_failed(self, m_delete):
         m_delete.side_effect = sa.exc.IntegrityError(None, None, None)
-        bundle_delete_id = ents.Bundle.testing_create().id
+        bundle_delete_id = ents.Bundle.fake().id
 
         resp = self.client.get('/bundles/{}/delete'.format(bundle_delete_id))
 
@@ -1218,14 +1217,14 @@ class TestBundleCrud(ViewTestBase):
         assert ents.Bundle.query.get(bundle_delete_id)
 
     def test_list(self):
-        obj = ents.Bundle.testing_create()
+        obj = ents.Bundle.fake()
         resp = self.client.get('/bundles')
         assert resp.pyquery('.grid-header-add-link a').attr('href').startswith('/bundles/add')
         assert 'datagrid' in resp
         assert obj.name in resp
 
     def test_list_export(self):
-        ents.Bundle.testing_create()
+        ents.Bundle.fake()
         resp = self.client.get('/bundles?export_to=xlsx')
         assert resp.content_type == 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'  # noqa
 
@@ -1234,13 +1233,13 @@ class TestPermissionsView(ViewTestBase):
     permissions = 'auth-manage'
 
     def test_list(self):
-        ents.Permission.testing_create()
+        ents.Permission.fake()
         resp = self.client.get('/permissions')
         assert not resp.pyquery('.grid-header-add-link')
         assert 'datagrid' in resp
 
     def test_list_export(self):
-        ents.Permission.testing_create()
+        ents.Permission.fake()
         resp = self.client.get('/permissions?export_to=xlsx')
         assert resp.content_type == 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'  # noqa
 
@@ -1252,13 +1251,13 @@ class TestGetCurrentUser:
 
     def test_flask_login_user_returned(self):
         with flask.current_app.test_request_context():
-            user = ents.User.testing_create()
+            user = ents.User.fake()
             flask_login.login_user(user)
             assert get_current_user().id == user.id
 
     def test_request_loader_user_returned(self):
         with flask.current_app.test_request_context():
-            user = ents.User.testing_create()
+            user = ents.User.fake()
             jwt_auth = flask.current_app.auth_manager.get_request_loader('jwt')
             token = jwt_auth.create_access_token(user)
             flask.request.headers = MultiDict([
@@ -1309,29 +1308,9 @@ class TestViewTestBase:
             Foo.setup_class()
 
 
-class TestFormSelect2(ViewTestBase):
-    permissions = 'auth-manage'
-    script = ('<script src="https://cdnjs.cloudflare.com/ajax/libs/select2/'
-              '4.0.10/js/select2.min.js"></script>')
-    style = ('<link href="https://cdnjs.cloudflare.com/ajax/libs/select2/'
-             '4.0.10/css/select2.min.css" rel="stylesheet" />')
-
-    @mock.patch.dict(flask.current_app.config, {'KEGAUTH_USE_SELECT2': True})
-    def test_renders_select2_links(self):
-        resp = self.client.get('/users/add')
-        assert self.script in resp
-        assert self.style in resp
-
-    @mock.patch.dict(flask.current_app.config, {'KEGAUTH_USE_SELECT2': False})
-    def test_select2_not_used(self):
-        resp = self.client.get('/users/add')
-        assert self.script not in resp
-        assert self.style not in resp
-
-
 @pytest.fixture
 def auth_user():
-    user = ents.User.testing_create()
+    user = ents.User.fake()
     yield user
 
 
@@ -1397,7 +1376,7 @@ class TestOAuthLogin:
 
 
 class TestOAuthAuthorize:
-    def setup(self):
+    def setup_method(self):
         ents.User.delete_cascaded()
 
     def test_profile_not_found(self, oauth_client):
@@ -1405,7 +1384,7 @@ class TestOAuthAuthorize:
         client.get('/oauth-authorize/foo', status=404)
 
     def test_user_found(self, oauth_client):
-        auth_user = ents.User.testing_create(email='foo@mycompany.biz')
+        auth_user = ents.User.fake(email='foo@mycompany.biz')
         client = AuthTestApp(flask.current_app)
         with mock.patch.object(oauth_client, 'authorize_access_token') as m_auth:
             m_auth.return_value = {'userinfo': {'email': auth_user.email}}
@@ -1414,7 +1393,7 @@ class TestOAuthAuthorize:
             assert resp.flashes == [('success', 'Login successful.')]
 
     def test_user_found_alt_token_path(self, oauth_client):
-        auth_user = ents.User.testing_create(email='foo@mycompany.biz')
+        auth_user = ents.User.fake(email='foo@mycompany.biz')
         client = AuthTestApp(flask.current_app)
         with mock.patch.object(oauth_client, 'authorize_access_token') as m_auth:
             m_auth.return_value = {}
@@ -1432,117 +1411,9 @@ class TestOAuthAuthorize:
             assert 'No user account matches' in resp
 
     def test_user_inactive(self, oauth_client):
-        auth_user = ents.User.testing_create(email='foo@mycompany.biz', is_enabled=False)
+        auth_user = ents.User.fake(email='foo@mycompany.biz', is_enabled=False)
         client = AuthTestApp(flask.current_app)
         with mock.patch.object(oauth_client, 'authorize_access_token') as m_auth:
             m_auth.return_value = {'userinfo': {'email': auth_user.email}}
             resp = client.get('/oauth-authorize/google')
             assert 'has been disabled' in resp
-
-
-@pytest.fixture
-def oidc_client():
-    client = AuthTestApp(flask.current_app)
-
-    with mock.patch.dict(
-        flask.current_app.config,
-        {
-            'OIDC_CLIENT_SECRETS': 'notreallyneeded',
-            'OIDC_COOKIE_SECURE': False,
-            'OIDC_CALLBACK_ROUTE': '/oidc/callback',
-            'OIDC_SCOPES': ('openid', 'email', 'profile'),
-            'OIDC_REDIRECT_BASE': 'http://localhost:5000',
-            'OIDC_LOGOUT': '/oauth2/v1/logout',
-            'OIDC_PROVIDER_URL': 'https://the.provider',
-            'OIDC_CLIENT_ID': 'theproviderclientid',
-            'OIDC_CLIENT_SECRET': 'supersecretrandomgeneratedstring',
-        }
-    ):
-        from keg_auth.libs.authenticators import OidcAuthenticator
-
-        # clean up app so OIDC can set up again
-        flask.current_app._got_first_request = False
-        flask.current_app.view_functions.pop('_oidc_callback', None)
-
-        # set up OIDC handler and attach it to the app
-        authenticator = OidcAuthenticator(flask.current_app)
-
-        with mock.patch.object(
-            flask.current_app.auth_manager,
-            'login_authenticator',
-            authenticator
-        ):
-            yield client
-
-
-@pytest.fixture
-def oidc_auth_client(oidc_client, auth_user):
-    username = auth_user.username
-
-    def _token_setter():
-        flask.g.oidc_id_token = 'foobar'
-
-    def _field_getter(fieldname):
-        return username
-
-    with mock.patch.dict(
-        flask.current_app.auth_manager.oidc.__dict__,
-        {
-            'authenticate_or_redirect': _token_setter,
-            'user_getfield': _field_getter,
-        },
-    ):
-        yield oidc_client
-
-
-@pytest.mark.skip('flask-oidc is broken against latest itsdangerous')
-class TestOidcLogin:
-    def test_authenticated(self, oidc_auth_client):
-        resp = oidc_auth_client.get('/login', status=302)
-        assert resp.location == '/'
-
-    def test_inactive(self, oidc_auth_client, auth_user):
-        ents.User.edit(auth_user.id, is_enabled=False)
-        resp = oidc_auth_client.get('/login', status=200)
-        assert 'has been disabled' in resp
-
-    def test_not_exists(self, oidc_auth_client):
-        ents.User.delete_cascaded()
-        resp = oidc_auth_client.get('/login', status=200)
-        assert 'No user account matches' in resp
-
-    def test_unauthenticated(self, oidc_client):
-        resp = oidc_client.get('/login', status=302)
-        assert 'oauth2/v1/authorize?' in resp.location
-
-
-@pytest.mark.skip('flask-oidc is broken against latest itsdangerous')
-class TestOidcLogout:
-    def test_unauthenticated(self, oidc_client):
-        resp = oidc_client.get('/logout', status=302)
-        assert resp.location == '/login'
-
-    def test_bad_token(self, oidc_auth_client):
-        resp = oidc_auth_client.get('/logout', status=302)
-        assert resp.location == '/login?next=%2Flogout'
-
-    def test_success(self, oidc_auth_client, auth_user):
-        with mock.patch.object(
-            flask.current_app.auth_manager.oidc,
-            'credentials_store',
-            {auth_user.username: 'bar'},
-        ), mock.patch(
-            'oauth2client.client.OAuth2Credentials.from_json',
-            lambda _: BlankObject(token_response={'id_token': 'foo'})
-        ):
-            resp = oidc_auth_client.get('/logout', status=302)
-            assert '/oauth2/v1/logout?id_token_hint=foo&post_logout_redirect_uri' \
-                in resp.location
-
-    def test_success_redirect(self, oidc_auth_client, auth_user):
-        with mock.patch.dict(
-            flask.current_app.config,
-            {'KEGAUTH_OIDC_LOGOUT_REDIRECT': 'http://foo'}
-        ):
-            resp = oidc_auth_client.get('/logout', status=302)
-            assert '/foo' in resp.location
